@@ -1,8 +1,6 @@
-import os
 import hashlib
 import json
 from datetime import date, datetime
-import warnings
 
 import certifi
 import requests
@@ -28,13 +26,6 @@ from juriscraper.lib.string_utils import (
 from juriscraper.lib.test_utils import MockRequest
 
 logger = make_default_logger()
-phantomjs_executable_path = "/usr/local/bin/phantomjs"
-_legacy_path = "/usr/local/phantomjs/phantomjs"
-if os.path.isfile(_legacy_path) and os.access(_legacy_path, os.X_OK):
-    phantomjs_executable_path = _legacy_path
-    msg = """Please place phantomjs executable in /usr/local/bin.
-    See https://github.com/freelawproject/juriscraper/pull/241"""
-    warnings.warn(msg, DeprecationWarning)
 
 
 class AbstractSite(object):
@@ -75,6 +66,10 @@ class AbstractSite(object):
         self._req_attrs = []
         self._all_attrs = []
 
+    def __del__(self):
+        if self.request["session"]:
+            self.request["session"].close()
+
     def __str__(self):
         out = []
         for attr, val in self.__dict__.items():
@@ -298,15 +293,6 @@ class AbstractSite(object):
         """
         self.hash = hashlib.sha1(str(self.case_names).encode()).hexdigest()
 
-    def _get_adapter_instance(self):
-        """Hook for returning a custom HTTPAdapter
-
-        This function allows subclasses to do things like explicitly set
-        specific SSL configurations when being called. Certain courts don't work
-        unless you specify older versions of SSL.
-        """
-        return HTTPAdapter()
-
     def _make_html_tree(self, text):
         """Hook for custom HTML parsers
 
@@ -355,7 +341,6 @@ class AbstractSite(object):
             self.request["verify"] = parameters["verify"]
             del parameters["verify"]
         self.request["parameters"] = parameters
-        self.request["session"].mount("https://", self._get_adapter_instance())
 
     def _request_url_get(self, url):
         """Execute GET request and assign appropriate request dictionary
@@ -403,7 +388,12 @@ class AbstractSite(object):
                 if six.PY2:
                     payload = self.request["response"].text
                 else:
-                    payload = str(self.request["response"].content)
+                    try:
+                        payload = self.request["response"].content.decode(
+                            "utf8"
+                        )
+                    except:
+                        payload = self.request["response"].text
 
                 text = self._clean_text(payload)
                 html_tree = self._make_html_tree(text)
