@@ -13,6 +13,7 @@ class Site(conn.Site):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         self.crawl_date = date.today()
-        self.url = 'http://www.jud.ct.gov/external/supapp/archiveAROap{year}.htm'.format(
-            year=self.crawl_date.strftime("%y"))
+        self.url = "http://www.jud.ct.gov/external/supapp/archiveAROap{year}.htm".format(
+            year=self.crawl_date.strftime("%y")
+        )
         self.court_id = self.__module__
