@@ -22,4 +22,4 @@ class Site(hawapp.Site):
         else:
             # This simply aborts the crawler.
             self.status = 200
-            self.html = html.fromstring('<html></html>')
+            self.html = html.fromstring("<html></html>")
