@@ -13,25 +13,26 @@ History:
 """
 import six
 from lxml import html
-
 from juriscraper.OpinionSite import OpinionSite
 from juriscraper.lib.string_utils import convert_date_string, clean_if_py3
 
 
 class Site(OpinionSite):
     # Skip first row of table, it's a header
-    starting_table_row = "//table//tr[position() > 1]"
+    path_table_row_start = "//table//tr[position() > 1]"
     # Skip rows that don't have  link in 4th cell with
     # either 'Opinion', 'Order', 'ORDER', or 'Amend' in
     # the link text
-    row_path_conditional = (
-        "/td[4]//a["
+    path_conditional_anchor = (
+        "a["
         'contains(.//text(), "Opinion") or '
         'contains(.//text(), "Order") or '
         'contains(.//text(), "ORDER") or '
-        'contains(.//text(), "Amended")]'
+        'contains(.//text(), "Amended")'
+        "]"
     )
-    base_path = "%s[./%s]" % (starting_table_row, row_path_conditional)
+    path_conditional_row = "/td[4]//%s" % path_conditional_anchor
+    path_base = "%s[./%s]" % (path_table_row_start, path_conditional_row)
 
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
@@ -40,7 +41,7 @@ class Site(OpinionSite):
 
     def _get_case_names(self):
         case_names = []
-        path = "%s/td[3]" % self.base_path
+        path = "%s/td[3]" % self.path_base
         for cell in self.html.xpath(path):
             name_string = html.tostring(
                 cell, method="text", encoding="unicode"
@@ -53,17 +54,28 @@ class Site(OpinionSite):
     def _get_download_urls(self):
         # We'll accept an order document if the opinion document
         # is missing. But we obviously prefer the opinion doc,
-        # so we put it first in the order below, and we take the
-        # first link that matches in path in each 4th cell.
-        path = "%s%s[1]/@href" % (
-            self.starting_table_row,
-            self.row_path_conditional,
-        )
-        return [url for url in self.html.xpath(path)]
+        # as indicated in the algorithm below. Since each row
+        # can list multiple valid links, we will parse all
+        # acceptable links, take the opinion link if present,
+        # otherwise take the first acceptable link.
+        opinion_urls = []
+        path = "%s/td[4]" % self.path_base
+        path_link = ".//%s" % self.path_conditional_anchor
+        for cell in self.html.xpath(path):
+            urls = []
+            url_opinion = False
+            for link in cell.xpath(path_link):
+                text = link.text_content().strip()
+                url = link.attrib["href"]
+                urls.append(url)
+                if "Opinion" in text:
+                    url_opinion = url
+            opinion_urls.append(url_opinion if url_opinion else urls[0])
+        return opinion_urls
 
     def _get_case_dates(self):
         case_dates = []
-        path = "%s/td[1]" % self.base_path
+        path = "%s/td[1]" % self.path_base
         for cell in self.html.xpath(path):
             date_string = html.tostring(
                 cell, method="text", encoding="unicode"
@@ -79,7 +91,7 @@ class Site(OpinionSite):
         return case_dates
 
     def _get_docket_numbers(self):
-        path = "%s/td[2]//text()" % self.base_path
+        path = "%s/td[2]//text()" % self.path_base
         return [text.strip() for text in self.html.xpath(path) if text.strip()]
 
     def _get_precedential_statuses(self):
