@@ -13,7 +13,7 @@ from datetime import date, datetime
 from lxml import html
 from lxml.html import tostring
 
-from juriscraper.AbstractSite import logger, phantomjs_executable_path
+from juriscraper.AbstractSite import logger
 from juriscraper.OpinionSiteWebDriven import OpinionSiteWebDriven
 from juriscraper.lib.html_utils import fix_links_in_lxml_tree
 from juriscraper.lib.string_utils import clean_if_py3
@@ -121,7 +121,7 @@ class Site(OpinionSiteWebDriven):
 
     def _get_judges(self):
         path = "{base}/following::td[2]".format(base=self.base_path)
-        return map(self._return_judge, self.html.xpath(path))
+        return list(map(self._return_judge, self.html.xpath(path)))
 
     @staticmethod
     def _return_judge(e):
