@@ -12,8 +12,9 @@ from lxml import html
 from juriscraper.OpinionSite import OpinionSite
 from juriscraper.opinions.united_states.state import me
 
+
 class Site(me.Site):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.url = 'http://www.courts.maine.gov/opinions_orders/supreme/lawcourt/2013/2013_index.shtml'
+        self.url = "http://www.courts.maine.gov/opinions_orders/supreme/lawcourt/2013/2013_index.shtml"
